import request from '@/utils/request'

// 查询个人用户信息列表
export function listOneself(query) {
    return request({
        url: '/system/personal/list',
        method: 'get',
        params: query
    })
}

// 查询个人用户信息详细
export function getOneself(userId) {
    return request({
        url: '/system/personal/' + userId,
        method: 'get'
    })
}

// 新增个人用户信息
export function addOneself(data) {
    return request({
        url: '/system/personal',
        method: 'post',
        data: data
    })
}

// 修改个人用户信息
export function updateOneself(data) {
    return request({
        url: '/system/personal',
        method: 'put',
        data: data
    })
}

// 删除个人用户信息
export function delOneself(userId) {
    return request({
        url: '/system/personal/' + userId,
        method: 'delete'
    })
}

// 导出个人用户信息
export function exportOneself(query) {
    return request({
        url: '/system/personal/export',
        method: 'get',
        params: query
    })
}
